<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * URL Base dos Assets
 *
 * Retorna a URL base dos assets, levando em conta as configurações
 * assets_directory e assets_version.
 *
 * A principal utilidade disso é poder utilizar "pseudo-versões" no
 * diretório de assets, para invalidar os arquivos que ficaram em caches,
 * quando necessário.
 *
 * Os assets devem ser referenciados da seguinte forma, por exemplo:
 * assets_url('css/arquivo123.css')
 *
 * @params string $uri Caminho do arquivo dentro do diretório de assets
 * @return string URL do arquivo de asset
 */
if ( ! function_exists('assets_url'))
{
	function assets_url($uri = '')
	{
		$CI =& get_instance();
		$CI->load->helper('url');
		return base_url(
			(rtrim($CI->config->item('assets_directory'), '/'))
			.'/'.$CI->config->item('assets_version')
			.'/'.$uri
		);
	}
}

/**
 * Cria rótulo a partir de um título, nome etc.
 *
 * @param string $str String a ser transformada em rótulo
 * @return string Rótulo
 */
if ( ! function_exists('rotulo'))
{
	function rotulo($str)
	{
		$CI =& get_instance();
		$CI->load->helper('url');
		$CI->load->helper('text');
		return strtolower(url_title(convert_accented_characters(character_limiter($str, 60, NULL))));
	}

}

/*
 * Retorna a URL base das imagens, levando em conta as configurações de img_directory
 * @params string $uri Caminho da imagem dentro do diretório de imagens, string $tam tamanho da imagem default caso não tever passado o uri
 * @return string URL da imagem
*/
if ( ! function_exists('imagens_url'))
{
	function imagens_url($uri = '', $tam = 'default_thumb')
	{
		$CI =& get_instance();
		if(empty($uri))
		{
			return base_url($CI->config->item($tam));
		}
		return base_url(
			(rtrim($CI->config->item('img_directory'), '/'))
			.'/'.$uri
		);
	}
}

// End of file